@@ -1,15 +1,14 @@
 /*
  * kbiff.cpp
- * Copyright (C) 1999-2001 Kurt Granroth <granroth@kde.org>
+ * Copyright (C) 1999-2002 Kurt Granroth <granroth@kde.org>
  *
  * This file contains the implementation of the main KBiff
  * widget
  *
- * $Id: kbiff.cpp,v 1.5 2001/10/22 22:35:29 gran Exp $
+ * $Id: kbiff.cpp,v 1.7 2002/04/14 06:55:22 gran Exp $
  */
 #include "kbiff.h"
 #include <qmovie.h>
-#include <qpopupmenu.h>
 #include <qtooltip.h>
 
 #include <kaudioplayer.h>
@@ -18,6 +17,7 @@
 #include <kiconloader.h>
 #include <klocale.h>
 #include <kmessagebox.h>
+#include <kpopupmenu.h>
 #include <kprocess.h>
 #include <krun.h>
 #include <kwin.h>
@@ -346,7 +346,7 @@ void KBiff::saveYourself()
 
 void KBiff::invokeHelp()
 {
-    kapp->invokeHTMLHelp("kbiff/kbiff.html", "");
+    kapp->invokeHelp();
 }
 
 void KBiff::displayPixmap()
@@ -393,7 +393,27 @@ void KBiff::displayPixmap()
         pixmap_name = noMailIcon;
 
     if (docked)
-        pixmap_name.prepend("mini-");
+    {
+        // we need to check if this has path info encoded into it
+        QFileInfo info(pixmap_name);
+
+        // if info.fileName() returns pixmap_name, then we no there
+        // isn't any paths attached and we can just prepend our 'mini'
+        if (info.fileName() == pixmap_name)
+            pixmap_name.prepend("mini-");
+        else
+        {
+            // so we have some path junk on it.  we get the filename
+            // by itself, prepend our 'mini' and tack it onto the end
+            // of the original dirpath.  simple
+            QString filename(info.fileName());
+            filename.prepend("mini-");
+
+            // we aren't guaranteed that the dirpath will end in a /
+            // so we add one (an extra one won't hurt, in any case
+            pixmap_name = info.dirPath() + "/" + filename;
+        }
+    }
     QString filename = KGlobal::iconLoader()->iconPath( pixmap_name, KIcon::User );
     QFileInfo file(filename);
 
@@ -639,7 +659,7 @@ void KBiff::start()
 ///////////////////////////////////////////////////////////////////////////
 void KBiff::popupMenu()
 {
-    QPopupMenu *popup = new QPopupMenu(0, "popup");
+    KPopupMenu *popup = new KPopupMenu(0, "popup");
 
     // if secure, disable everything but exit
     if (isSecure == false)
@@ -721,13 +741,11 @@ bool KBiff::isRunning()
 
 void KBiff::executeCommand(const QString& command)
 {
-  kdDebug(0) << "KBiff::executeCommand(" << command << ")" << endl;
     KRun::runCommand(command);
 }
 
 void KBiff::slotLaunchFetchClient(const QString& fetchClient)
 {
-    kdDebug(0) << "KBiff::slotLaunchFetchClient(" << fetchClient << ")" << endl;
     if (!fetchClient.isEmpty())
         executeCommand(fetchClient);
 }
