@@ -1,11 +1,11 @@
 /*
  * kbiffmonitor.cpp
- * Copyright (C) 1999-2001 Kurt Granroth <granroth@kde.org>
+ * Copyright (C) 1999-2002 Kurt Granroth <granroth@kde.org>
  *
  * This file contains the implementation of KBiffMonitor and
  * associated classes.
  *
- * $Id: kbiffmonitor.cpp,v 1.7 2001/10/23 19:52:18 gran Exp $
+ * $Id: kbiffmonitor.cpp,v 1.9 2002/03/25 19:21:28 gran Exp $
  */
 #include "kbiffmonitor.h"
 
@@ -162,7 +162,7 @@ void KBiffMonitor::saveConfig()
         uidlist.append(*UIDL);
     }
 
-    config->writeEntry("mailState", mailState);
+    config->writeEntry("mailState", (int)mailState);
     config->writeEntry("lastSize", lastSize);
     config->writeEntry("lastRead",lastRead);
     config->writeEntry("lastModified",lastModified);
