@@ -1,11 +1,11 @@
 /*
  * setupdlg.cpp
- * Copyright (C) 1999-2001 Kurt Granroth <granroth@kde.org>
+ * Copyright (C) 1999-2002 Kurt Granroth <granroth@kde.org>
  *
  * This file contains the implementation of the setup dialog
  * class for KBiff.
  *
- * $Id: setupdlg.cpp,v 1.6 2001/10/23 19:52:18 gran Exp $
+ * $Id: setupdlg.cpp,v 1.8 2002/04/14 06:55:22 gran Exp $
  */
 #include "setupdlg.h"
 
@@ -34,6 +34,7 @@
 #include <kfiledialog.h>
 #include <kapp.h>
 #include <kglobal.h>
+#include <kiconloader.h>
 #include <klocale.h>
 #include <kstddirs.h>
 #include <ksimpleconfig.h>
@@ -702,6 +703,40 @@ void KBiffGeneralTab::readConfig(const QString& profile)
   delete config;
 }
 
+static QString justIconName(const QString& icon_name)
+{
+  // the following code is a bit of a hack, but there is a rationale
+  // to it.  if possible, we want to just save the name of the icons
+  // (without extension), and not the whole path due to name munging
+  // later on.
+  QFileInfo info( icon_name );
+
+  // we first test if the basename (filename without extensions) is
+  // the same as the filename.  if it is, then we are perfect.  no
+  // need to do anything further
+  if ( info.baseName(true) == info.fileName() )
+    return icon_name;
+
+  // now we see if we can load based just on the basename
+  QPixmap icon = KGlobal::iconLoader()->loadIcon( info.baseName(true), KIcon::User );
+
+  // if it's null, then it's in a non-standard path so we must use an
+  // absolute path.  no need to go further
+  if ( icon.isNull() )
+    return icon_name;
+
+  // now we know that the icon loader can find it.. but is it the same
+  // one as the one the user picked?
+  if ( KGlobal::iconLoader()->iconPath( info.baseName(true), KIcon::User ) !=
+       KGlobal::iconLoader()->iconPath( icon_name, KIcon::User ) )
+    return icon_name;
+
+  // FINALLY done!  if we got this far, then we know that the icon
+  // loader can handle just the name and that the icon returned is the
+  // same one that the user wanted.  whew!
+  return info.baseName(true);
+}
+
 void KBiffGeneralTab::saveConfig(const QString& profile)
 {
   // open the config file for writing
@@ -714,10 +749,10 @@ void KBiffGeneralTab::saveConfig(const QString& profile)
   config->writeEntry("Docked", checkDock->isChecked());
   config->writeEntry("Sessions", checkNoSession->isChecked());
   config->writeEntry("DontCheck", checkNoStartup->isChecked());
-  config->writeEntry("NoMailPixmap", buttonNoMail->icon());
-  config->writeEntry("NewMailPixmap", buttonNewMail->icon());
-  config->writeEntry("OldMailPixmap", buttonOldMail->icon());
-  config->writeEntry("NoConnPixmap", buttonNoConn->icon());
+  config->writeEntry("NoMailPixmap", justIconName(buttonNoMail->icon()));
+  config->writeEntry("NewMailPixmap", justIconName(buttonNewMail->icon()));
+  config->writeEntry("OldMailPixmap", justIconName(buttonOldMail->icon()));
+  config->writeEntry("NoConnPixmap", justIconName(buttonNoConn->icon()));
   delete config;
 }
 
@@ -1585,7 +1620,7 @@ void KBiffMailboxTab::protocolSelected(int protocol)
             port = 143;
             timeout = 10;
             editMailbox->setEnabled(true);
-            buttonBrowse->setEnabled(false);
+            buttonBrowse->setEnabled(true);
             editServer->setEnabled(true);
             editUser->setEnabled(true);
             editPassword->setEnabled(true);
@@ -1626,18 +1661,42 @@ void KBiffMailboxTab::protocolSelected(int protocol)
 
 void KBiffMailboxTab::browse()
 {
-  QString file;
+  QString proto(getMailbox().protocol());
 
-  if (getMailbox().protocol() == "maildir")
-    file = KFileDialog::getExistingDirectory();
-  else
-    file = KFileDialog::getOpenFileName();
-
-  if( file.isEmpty() )
-    return;
-
-  if( !file.isEmpty() )
+  if (proto == "imap4")
   {
+    KURL start;
+    start.setProtocol("imap");
+    start.setUser(getMailbox().user());
+    start.setHost(getMailbox().host());
+    start.setPath("/");
+    KURL url = KFileDialog::getOpenURL(start.url());
+    if (url.url().isEmpty())
+      return;
+    
+    QString path(url.path());
+    if (path.isEmpty())
+      return;
+
+    if (path[0] == '/')
+      path = path.right(path.length() - 1);
+    if (path.right(1) == "/")
+      path = path.left(path.length() - 1);
+
+    editMailbox->setText( path );
+    return;
+  }
+  else
+  {
+    QString file;
+    if (proto == "maildir")
+      file = KFileDialog::getExistingDirectory();
+    else
+      file = KFileDialog::getOpenFileName();
+
+    if( file.isEmpty() )
+      return;
+
     editMailbox->setText( file );
   }
 }
@@ -1725,7 +1784,7 @@ KBiffAboutTab::KBiffAboutTab(QWidget *parent)
                       SLOT(homepage(const QString&)));
 
   QLabel *version_label = new QLabel(this);
-  version_label->setText(QString("Version %1\n\nCopyright (C) 1998-2001\nKurt Granroth").arg("3.5.4"));
+  version_label->setText(QString("Version %1\n\nCopyright (C) 1998-2002\nKurt Granroth").arg("3.6.1"));
 
   KURLLabel *email_label = new KURLLabel(this);
   email_label->setText("granroth@kde.org");
