@@ -1,11 +1,11 @@
 /*
  * status.cpp
- * Copyright (C) 1999-2001 Kurt Granroth <granroth@kde.org>
+ * Copyright (C) 1999-2002 Kurt Granroth <granroth@kde.org>
  *
  * This file contains the implementation of the KBiffStatus
  * widget
  *
- * $Id: status.cpp,v 1.4 2001/08/03 22:52:11 gran Exp $
+ * $Id: status.cpp,v 1.5 2002/03/25 19:21:28 gran Exp $
  */
 #include "status.h"
 
@@ -19,7 +19,7 @@
 #include <qpoint.h>
 
 KBiffStatus::KBiffStatus(const QString& profile, const KBiffStatusList& list)
-    : QFrame(0, 0, WStyle_Customize | WStyle_NoBorder),
+    : QFrame(0, 0, WType_Popup),
       _listView(new QListView(this))
 {
     setFrameStyle(WinPanel|Raised);
@@ -70,7 +70,8 @@ void KBiffStatus::popup(const QPoint& pos)
     int x = pos.x(), y = pos.y();
 
     // for some reason, the width and height are incorrect until
-    // we do the show.  so we show first and move later
+    // we do the show.  so we show first (after hiding) and move later
+    move(-100, -100);
     show();
 
     // verify that the width is within the desktop
